@@ -141,14 +141,19 @@ class Pair:
             pair = self
             pair.horizontal = horizontal
             self.one, self.two = q
+            final_pair = pair
+
         else:
             pair = Pair(horizontal=horizontal)
             if self.one == existing_window_id:
                 self.one = pair
             else:
                 self.two = pair
-            tuple(map(pair.balanced_add, q))
-        return pair
+            for wid in q:
+                qp = pair.balanced_add(wid)
+                if wid == new_window_id:
+                    final_pair = qp
+        return final_pair
 
     def apply_window_geometry(
         self, window_id: int,
@@ -418,10 +423,14 @@ class Pair:
 
 class SplitsLayoutOpts(LayoutOpts):
 
-    default_axis_is_horizontal: bool = True
+    default_axis_is_horizontal: Optional[bool] = True
 
     def __init__(self, data: Dict[str, str]):
-        self.default_axis_is_horizontal = data.get('split_axis', 'horizontal') == 'horizontal'
+        q = data.get('split_axis', 'horizontal')
+        if q == 'auto':
+            self.default_axis_is_horizontal = None
+        else:
+            self.default_axis_is_horizontal = q == 'horizontal'
 
     def serialized(self) -> Dict[str, Any]:
         return {'default_axis_is_horizontal': self.default_axis_is_horizontal}
@@ -434,14 +443,17 @@ class Splits(Layout):
     no_minimal_window_borders = True
 
     @property
-    def default_axis_is_horizontal(self) -> bool:
+    def default_axis_is_horizontal(self) -> Optional[bool]:
         return self.layout_opts.default_axis_is_horizontal
 
     @property
     def pairs_root(self) -> Pair:
         root: Optional[Pair] = getattr(self, '_pairs_root', None)
         if root is None:
-            self._pairs_root = root = Pair(horizontal=self.default_axis_is_horizontal)
+            horizontal = self.default_axis_is_horizontal
+            if horizontal is None:
+                horizontal = True
+            self._pairs_root = root = Pair(horizontal=horizontal)
         return root
 
     @pairs_root.setter
@@ -483,7 +495,8 @@ class Splits(Layout):
         self,
         all_windows: WindowList,
         window: WindowType,
-        location: Optional[str]
+        location: Optional[str],
+        bias: Optional[float] = None,
     ) -> None:
         horizontal = self.default_axis_is_horizontal
         after = True
@@ -494,20 +507,27 @@ class Splits(Layout):
         elif location in ('before', 'first'):
             after = False
         aw = all_windows.active_window
+        if bias:
+            bias = max(0, min(abs(bias), 100)) / 100
         if aw is not None:
             ag = all_windows.active_group
             assert ag is not None
             group_id = ag.id
             pair = self.pairs_root.pair_for_window(group_id)
             if pair is not None:
-                if location == 'split':
+                if location == 'split' or horizontal is None:
                     wwidth = aw.geometry.right - aw.geometry.left
                     wheight = aw.geometry.bottom - aw.geometry.top
                     horizontal = wwidth >= wheight
                 target_group = all_windows.add_window(window, next_to=aw, before=not after)
-                pair.split_and_add(group_id, target_group.id, horizontal, after)
+                parent_pair = pair.split_and_add(group_id, target_group.id, horizontal, after)
+                if bias is not None:
+                    parent_pair.bias = bias if parent_pair.one == target_group.id else (1 - bias)
                 return
         all_windows.add_window(window)
+        p = self.pairs_root.balanced_add(window.id)
+        if bias is not None:
+            p.bias = bias
 
     def modify_size_of_window(
         self,
@@ -601,21 +621,27 @@ class Splits(Layout):
                         pair.one, pair.two = pair.two, pair.one
                     return True
         elif action_name == 'move_to_screen_edge':
-            args = args or ('left',)
-            which = args[0]
-            horizontal = which in ('left', 'right')
-            wg = all_windows.active_group
-            if wg is not None:
-                self.remove_windows(wg.id)
-                new_root = Pair(horizontal)
-                if which in ('left', 'top'):
-                    new_root.balanced_add(wg.id)
-                    new_root.two = self.pairs_root
-                else:
-                    new_root.one = self.pairs_root
-                    new_root.two = wg.id
-                self.pairs_root = new_root
-                return True
+            count = 0
+            for wid in self.pairs_root.all_window_ids():
+                count += 1
+                if count > 1:
+                    break
+            if count > 1:
+                args = args or ('left',)
+                which = args[0]
+                horizontal = which in ('left', 'right')
+                wg = all_windows.active_group
+                if wg is not None:
+                    self.remove_windows(wg.id)
+                    new_root = Pair(horizontal)
+                    if which in ('left', 'top'):
+                        new_root.balanced_add(wg.id)
+                        new_root.two = self.pairs_root
+                    else:
+                        new_root.one = self.pairs_root
+                        new_root.two = wg.id
+                    self.pairs_root = new_root
+                    return True
 
         return None
 
